import os
os.environ['OPENBLAS_NUM_THREADS'] = '1'

import time
import logging
import telebot
from pytrends.request import TrendReq
import pandas as pd

# تنظیمات ربات تلگرام
API_TOKEN = "7043250221:AAGzMhNv97dlFsSWbKwdRBlSoH_1TP9P5xQ"
bot = telebot.TeleBot(API_TOKEN)

# تنظیمات PyTrends بدون پارامترهای اضافی
pytrends = TrendReq(
    hl='fa-IR',
    tz=210
)

def get_related_queries(keyword):
    """دریافت عبارات جستجوی مرتبط"""
    try:
        # ساخت payload با حداکثر تلاش
        for attempt in range(3):  # سه بار تلاش
            try:
                pytrends.build_payload(
                    kw_list=[keyword],
                    timeframe='now 7-d',
                    geo='IR'
                )
                related_queries = pytrends.related_queries()
                break
            except Exception as e:
                if attempt == 2:  # آخرین تلاش
                    return [f"❌ خطا در دریافت داده‌ها: {str(e)}"]
                time.sleep(2)
                continue

        # بررسی نتایج
        if not related_queries or keyword not in related_queries:
            return ["❌ عبارت مرتبطی یافت نشد."]

        results = []

        # دریافت عبارات پرتکرار
        top_df = related_queries.get(keyword, {}).get('top', pd.DataFrame())
        if isinstance(top_df, pd.DataFrame) and not top_df.empty:
            results.append("🔝 عبارات پرجستجو:")
            for index, row in top_df.iterrows():
                try:
                    query = str(row.get('query', '')).strip()
                    value = int(row.get('value', 0))
                    if query and value > 0:
                        results.append(f"  • {query}: {value}%")
                except Exception as e:
                    logging.error(f"خطا در پردازش عبارات پرجستجو: {str(e)}")
                    continue

        # دریافت عبارات در حال رشد
        rising_df = related_queries.get(keyword, {}).get('rising', pd.DataFrame())
        if isinstance(rising_df, pd.DataFrame) and not rising_df.empty:
            if results:  # اگر قبلاً نتیجه‌ای داشتیم، یک خط خالی اضافه کنیم
                results.append("")
            results.append("📈 عبارات در حال رشد:")
            for index, row in rising_df.iterrows():
                try:
                    query = str(row.get('query', '')).strip()
                    value = row.get('value', '')
                    if query:
                        if value == 'Breakout':
                            results.append(f"  • {query}: 🚀 رشد انفجاری")
                        else:
                            try:
                                value = int(float(value))
                                results.append(f"  • {query}: +{value}%")
                            except Exception as e:
                                logging.error(f"خطا در پردازش عبارات در حال رشد: {str(e)}")
                                continue
                except Exception as e:
                    logging.error(f"خطا در پردازش عبارات در حال رشد: {str(e)}")
                    continue

        if len(results) <= 2:  # اگر فقط هدرها باشند
            return ["❌ عبارت مرتبطی یافت نشد."]

        return results

    except Exception as e:
        logging.error(f"خطا در دریافت عبارات مرتبط: {str(e)}")
        return [f"❌ خطا در دریافت داده‌ها: {str(e)}"]

@bot.message_handler(commands=['start'])
def send_welcome(message):
    welcome_text = """
🔍 سلام! به ربات جستجوی ترندها خوش آمدید!

برای دیدن عبارات مرتبط و ترند، کافیست کلمه یا عبارت مورد نظر خود را بنویسید.

💡 نکته: هر چه عبارت شما دقیق‌تر باشد، نتایج بهتری دریافت خواهید کرد.

مثال‌ها:
- موسیقی پاپ
- فیلم ایرانی
- بازی کامپیوتر
    """
    bot.reply_to(message, welcome_text)

@bot.message_handler(func=lambda message: True)
def handle_message(message):
    keyword = message.text.strip()

    if not keyword:
        bot.reply_to(message, "❌ لطفاً یک عبارت معتبر وارد کنید.")
        return

    if len(keyword) < 2:
        bot.reply_to(message, "❌ لطفاً عبارت طولانی‌تری وارد کنید.")
        return

    processing_message = bot.send_message(
        message.chat.id,
        f"🔍 در حال جستجوی عبارات مرتبط با '{keyword}'..."
    )

    try:
        results = get_related_queries(keyword)

        if results and not results[0].startswith("❌"):
            response = "\n".join(results)
            bot.send_message(
                message.chat.id,
                f"📊 نتایج جستجو برای '{keyword}':\n\n{response}",
                parse_mode='HTML'
            )
        else:
            bot.send_message(
                message.chat.id,
                results[0]  # نمایش پیام خطا
            )

    except Exception as e:
        bot.send_message(
            message.chat.id,
            f"❌ خطایی رخ داد: {str(e)}\nلطفاً دوباره تلاش کنید."
        )

    finally:
        try:
            bot.delete_message(  # حذف پیام "در حال جستجو"
                message.chat.id,
                processing_message.message_id
            )
        except:
            pass

def main():
    print("🚀 ربات در حال اجرا...")
    while True:
        try:
            bot.polling(none_stop=True, interval=0)
        except Exception as e:
            print(f"خطا در اجرای ربات: {e}")
            time.sleep(10)

if __name__ == "__main__":
    main()
